﻿using System.Data;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 그리드 컨트롤을 설정한다.

            this.gridView.OptionsDetail.EnableMasterViewMode = false;
            this.gridView.OptionsSelection.MultiSelect       = true;
            this.gridView.OptionsSelection.MultiSelectMode   = GridMultiSelectMode.CellSelect;
            this.gridView.FocusRectStyle                     = DrawFocusRectStyle.CellFocus;

            this.gridView.OptionsView.ShowGroupPanel = false;

            this.gridView.IndicatorWidth                         = 30;
            this.gridView.OptionsView.ShowIndicator              = true;
            this.gridView.OptionsView.EnableAppearanceEvenRow    = false;
            this.gridView.OptionsView.EnableAppearanceOddRow     = false;
            this.gridView.OptionsBehavior.KeepFocusedRowOnUpdate = false;
            this.gridView.OptionsNavigation.AutoFocusNewRow      = true;

            this.gridView.OptionsBehavior.AutoPopulateColumns      = true;
            this.gridView.OptionsView.ShowColumnHeaders            = true;
            this.gridView.OptionsView.ColumnAutoWidth              = false;
            this.gridView.OptionsMenu.EnableColumnMenu             = false;
            this.gridView.OptionsNavigation.EnterMoveNextColumn    = true;
            this.gridView.OptionsCustomization.AllowColumnMoving   = false;
            this.gridView.OptionsCustomization.AllowColumnResizing = true;
            this.gridView.OptionsCustomization.AllowFilter         = false;
            this.gridView.OptionsCustomization.AllowSort           = false;

            this.gridView.OptionsView.ShowButtonMode                   = ShowButtonModeEnum.ShowForFocusedCell;
            this.gridView.OptionsView.AllowCellMerge                   = false;
            this.gridView.OptionsBehavior.EditorShowMode               = EditorShowMode.Default;
            this.gridView.OptionsBehavior.Editable                     = true;
            this.gridView.OptionsSelection.EnableAppearanceFocusedCell = false;
            this.gridView.OptionsSelection.InvertSelection             = false;
            this.gridView.OptionsHint.ShowCellHints                    = false;
            this.gridView.OptionsClipboard.CopyColumnHeaders           = DefaultBoolean.False;

            #endregion

            this.bindingSource.DataSource = GetDataTable();

            this.value1TextEdit.DataBindings.Add("EditValue", this.bindingSource, "value1");
            this.value2MemoEdit.DataBindings.Add("EditValue", this.bindingSource, "value2");
            this.value3MemoEdit.DataBindings.Add("EditValue", this.bindingSource, "value3");

            this.gridControl.DataSource = this.bindingSource;

            this.gridView.BestFitColumns();

            this.dataNavigator.DataSource = this.bindingSource;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 데이터 테이블 구하기 - GetDataTable()

        /// <summary>
        /// 데이터 테이블 구하기
        /// </summary>
        /// <returns>데이터 테이블</returns>
        private DataTable GetDataTable()
        {
            DataTable  table = new DataTable();
            DataColumn column;
            DataRow    row;

            column = new DataColumn();

            column.DataType      = typeof(int);
            column.ColumnName    = "value1";
            column.Caption       = "value1";
            column.AutoIncrement = false;
            column.ReadOnly      = false;
            column.Unique        = false;

            table.Columns.Add(column);

            column = new DataColumn();

            column.DataType      = typeof(int);
            column.ColumnName    = "value2";
            column.Caption       = "value2";
            column.AutoIncrement = false;
            column.ReadOnly      = false;
            column.Unique        = false;

            table.Columns.Add(column);

            column = new DataColumn();

            column.DataType      = typeof(int);
            column.Caption       = "value3";
            column.ColumnName    = "value3";
            column.AutoIncrement = false;
            column.ReadOnly      = false;
            column.Unique        = false;

            table.Columns.Add(column);

            for(int i = 0; i <= 100; i++)
            {
                row = table.NewRow();

                row["value1"] = i;
                row["value2"] = 10 * i;
                row["value3"] = 100 * i;

                table.Rows.Add(row);
            }

            table.AcceptChanges();

            return table;
        }

        #endregion
    }
}